fn written_pixel_info(
c: ExtendedColorType,
palette: Option<&[[u8; 3]]>,
) -> Result<(u32, u32, u32), ImageError>Expand description
Returns a tuple representing: (dib header size, written pixel size, palette color count).
fn written_pixel_info(
c: ExtendedColorType,
palette: Option<&[[u8; 3]]>,
) -> Result<(u32, u32, u32), ImageError>Returns a tuple representing: (dib header size, written pixel size, palette color count).